@@ -1,17 +1,13 @@
-from __future__ import unicode_literals
-
-import argparse
 import logging
 import re
+from urllib.parse import parse_qsl, urlparse, urlunparse
 
-from streamlink.compat import is_py2, parse_qsl, urlparse, urlunparse
-from streamlink.plugin import Plugin, PluginError, PluginArguments, PluginArgument
-from streamlink.plugin.api import validate, useragents
+from streamlink.plugin import Plugin, PluginError
+from streamlink.plugin.api import useragents, validate
 from streamlink.plugin.api.utils import itertags, parse_query
-from streamlink.stream import HTTPStream, HLSStream
+from streamlink.stream import HLSStream, HTTPStream
 from streamlink.stream.ffmpegmux import MuxedStream
 from streamlink.utils import parse_json, search_dict
-from streamlink.utils.encoding import maybe_decode
 
 log = logging.getLogger(__name__)
 
@@ -50,13 +46,11 @@ _config_schema = validate.Schema(
                 validate.optional("videoDetails"): {
                     validate.optional("isLive"): validate.transform(bool),
                     validate.optional("author"): validate.text,
-                    validate.optional("title"): validate.all(validate.text,
-                                                             validate.transform(maybe_decode))
+                    validate.optional("title"): validate.text
                 },
                 validate.optional("playabilityStatus"): {
                     validate.optional("status"): validate.text,
-                    validate.optional("reason"): validate.all(validate.text,
-                                                              validate.transform(maybe_decode)),
+                    validate.optional("reason"): validate.text
                 },
             },
         ),
@@ -64,8 +58,9 @@ _config_schema = validate.Schema(
     }
 )
 
-_ytdata_re = re.compile(r'window\["ytInitialData"\]\s*=\s*({.*?});', re.DOTALL)
-_url_re = re.compile(r"""(?x)https?://(?:\w+\.)?youtube\.com
+_ytdata_re = re.compile(r'ytInitialData\s*=\s*({.*?});', re.DOTALL)
+_url_re = re.compile(r"""
+    https?://(?:\w+\.)?youtube\.com
     (?:
         (?:
             /(?:
@@ -89,7 +84,9 @@ _url_re = re.compile(r"""(?x)https?://(?:\w+\.)?youtube\.com
             /(?:c/)?[^/?]+/live/?$
         )
     )
-""")
+    |
+    https?://youtu\.be/(?P<video_id_short>[0-9A-z_-]{11})
+""", re.VERBOSE)
 
 
 class YouTube(Plugin):
@@ -98,10 +95,8 @@ class YouTube(Plugin):
 
     _oembed_schema = validate.Schema(
         {
-            "author_name": validate.all(validate.text,
-                                        validate.transform(maybe_decode)),
-            "title": validate.all(validate.text,
-                                  validate.transform(maybe_decode))
+            "author_name": validate.text,
+            "title": validate.text
         }
     )
 
@@ -130,16 +125,8 @@ class YouTube(Plugin):
         258: 258,
     }
 
-    arguments = PluginArguments(
-        PluginArgument(
-            "api-key",
-            sensitive=True,
-            help=argparse.SUPPRESS  # no longer used
-        )
-    )
-
     def __init__(self, url):
-        super(YouTube, self).__init__(url)
+        super().__init__(url)
         parsed = urlparse(self.url)
         if parsed.netloc == 'gaming.youtube.com':
             self.url = urlunparse(parsed._replace(netloc='www.youtube.com'))
@@ -238,13 +225,21 @@ class YouTube(Plugin):
         return streams
 
     def _find_video_id(self, url):
-
         m = _url_re.match(url)
-        if m.group("video_id"):
+        video_id = m.group("video_id") or m.group("video_id_short")
+        if video_id:
             log.debug("Video ID from URL")
-            return m.group("video_id")
+            return video_id
 
         res = self.session.http.get(url)
+        if urlparse(res.url).netloc == "consent.youtube.com":
+            c_data = {}
+            for _i in itertags(res.text, "input"):
+                if _i.attributes.get("type") == "hidden":
+                    c_data[_i.attributes.get("name")] = _i.attributes.get("value")
+            log.debug(f"c_data_keys: {', '.join(c_data.keys())}")
+            res = self.session.http.post("https://consent.youtube.com/s", data=c_data)
+
         datam = _ytdata_re.search(res.text)
         if datam:
             data = parse_json(datam.group(1))
@@ -255,19 +250,27 @@ class YouTube(Plugin):
                     log.debug("Video ID from currentVideoEndpoint")
                     return video_id
             for x in search_dict(data, 'videoRenderer'):
+                if x.get("viewCountText", {}).get("runs"):
+                    if x.get("videoId"):
+                        log.debug("Video ID from videoRenderer (live)")
+                        return x["videoId"]
                 for bstyle in search_dict(x.get("badges", {}), "style"):
                     if bstyle == "BADGE_STYLE_TYPE_LIVE_NOW":
                         if x.get("videoId"):
                             log.debug("Video ID from videoRenderer (live)")
                             return x["videoId"]
 
-        if "/embed/live_stream" in url:
+        if urlparse(url).path.endswith(("/embed/live_stream", "/live")):
             for link in itertags(res.text, "link"):
                 if link.attributes.get("rel") == "canonical":
                     canon_link = link.attributes.get("href")
                     if canon_link != url:
-                        log.debug("Re-directing to canonical URL: {0}".format(canon_link))
-                        return self._find_video_id(canon_link)
+                        if canon_link.endswith("v=live_stream"):
+                            log.debug("The video is not available")
+                            break
+                        else:
+                            log.debug("Re-directing to canonical URL: {0}".format(canon_link))
+                            return self._find_video_id(canon_link)
 
         raise PluginError("Could not find a video on this page")
 
@@ -283,11 +286,11 @@ class YouTube(Plugin):
         info_parsed = None
         for _params in (_params_1, _params_2, _params_3):
             count += 1
-            params = {"video_id": video_id}
+            params = {"video_id": video_id, "html5": "1"}
             params.update(_params)
 
             res = self.session.http.get(self._video_info_url, params=params)
-            info_parsed = parse_query(res.content if is_py2 else res.text, name="config", schema=_config_schema)
+            info_parsed = parse_query(res.text, name="config", schema=_config_schema)
             player_response = info_parsed.get("player_response", {})
             playability_status = player_response.get("playabilityStatus", {})
             if (playability_status.get("status") != "OK"):
@@ -307,7 +310,7 @@ class YouTube(Plugin):
         is_live = False
 
         self.video_id = self._find_video_id(self.url)
-        log.debug("Using video ID: {0}", self.video_id)
+        log.debug(f"Using video ID: {self.video_id}")
 
         info = self._get_stream_info(self.video_id)
         if info and info.get("status") == "fail":
@@ -344,11 +347,11 @@ class YouTube(Plugin):
         if hls_manifest:
             try:
                 hls_streams = HLSStream.parse_variant_playlist(
-                    self.session, hls_manifest, namekey="pixels"
+                    self.session, hls_manifest, name_key="pixels"
                 )
                 streams.update(hls_streams)
-            except IOError as err:
-                log.warning("Failed to extract HLS streams: {0}", err)
+            except OSError as err:
+                log.warning(f"Failed to extract HLS streams: {err}")
 
         if not streams and protected:
             raise PluginError("This plugin does not support protected videos, "
